@@ -57,7 +57,9 @@
 
 /*** DOCUMENTATION
 	<application name="AgentLogin" language="en_US">
-		<since><version>12.0.0</version></since>
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Login an agent.
 		</synopsis>
@@ -106,7 +108,9 @@
 		</see-also>
 	</application>
 	<application name="AgentRequest" language="en_US">
-		<since><version>12.0.0</version></since>
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Request an agent to connect with the channel.
 		</synopsis>
@@ -132,7 +136,9 @@
 		</see-also>
 	</application>
 	<function name="AGENT" language="en_US">
-		<since><version>12.0.0</version></since>
+		<since>
+			<version>12.0.0</version>
+		</since>
 		<synopsis>
 			Gets information about an Agent
 		</synopsis>
@@ -184,7 +190,9 @@
 	</manager>
 	<managerEvent language="en_US" name="Agents">
 		<managerEventInstance class="EVENT_FLAG_AGENT">
-			<since><version>12.0.0</version></since>
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>
 				Response event in a series to the Agents AMI action containing
 				information about a defined agent.
@@ -210,11 +218,11 @@
 					<para>Present if Status value is <literal>AGENT_ONCALL</literal>.</para>
 				</parameter>
 				<parameter name="CallStarted">
-					<para>Epoche time when the agent started talking with the caller.</para>
+					<para>Epoch time when the agent started talking with the caller.</para>
 					<para>Present if Status value is <literal>AGENT_ONCALL</literal>.</para>
 				</parameter>
 				<parameter name="LoggedInTime">
-					<para>Epoche time when the agent logged in.</para>
+					<para>Epoch time when the agent logged in.</para>
 					<para>Present if Status value is <literal>AGENT_IDLE</literal> or <literal>AGENT_ONCALL</literal>.</para>
 				</parameter>
 				<channel_snapshot/>
@@ -230,7 +238,9 @@
 	</managerEvent>
 	<managerEvent language="en_US" name="AgentsComplete">
 		<managerEventInstance class="EVENT_FLAG_AGENT">
-			<since><version>12.0.0</version></since>
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>
 				Final response event in a series of events to the Agents AMI action.
 			</synopsis>
@@ -273,13 +283,17 @@
 				<synopsis>Unused, but reserved.</synopsis>
 			</configObject>
 			<configObject name="agent-id">
-				<since><version>12.0.0</version></since>
+				<since>
+					<version>12.0.0</version>
+				</since>
 				<synopsis>Configure an agent for the pool.</synopsis>
 				<description>
 					<xi:include xpointer="xpointer(/docs/configInfo[@name='app_agent_pool']/description/note)" />
 				</description>
 				<configOption name="ackcall">
-					<since><version>12.0.0</version></since>
+					<since>
+						<version>12.0.0</version>
+					</since>
 					<synopsis>Enable to require the agent to acknowledge a call.</synopsis>
 					<description>
 						<para>Enable to require the agent to give a DTMF acknowledgement
@@ -289,7 +303,9 @@
 					</description>
 				</configOption>
 				<configOption name="acceptdtmf">
-					<since><version>12.0.0</version></since>
+					<since>
+						<version>12.0.0</version>
+					</since>
 					<synopsis>DTMF key sequence the agent uses to acknowledge a call.</synopsis>
 					<description>
 						<note><para>The option is overridden by <variable>AGENTACCEPTDTMF</variable> on agent login.</para></note>
@@ -298,7 +314,9 @@
 					</description>
 				</configOption>
 				<configOption name="autologoff">
-					<since><version>12.0.0</version></since>
+					<since>
+						<version>12.0.0</version>
+					</since>
 					<synopsis>Time the agent has to acknowledge a call before being logged off.</synopsis>
 					<description>
 						<para>Set how many seconds a call for the agent has to wait for the
@@ -311,7 +329,9 @@
 					</description>
 				</configOption>
 				<configOption name="wrapuptime">
-					<since><version>12.0.0</version></since>
+					<since>
+						<version>12.0.0</version>
+					</since>
 					<synopsis>Minimum time the agent has between calls.</synopsis>
 					<description>
 						<para>Set the minimum amount of time in milliseconds after
@@ -321,14 +341,18 @@
 					</description>
 				</configOption>
 				<configOption name="musiconhold">
-					<since><version>12.0.0</version></since>
+					<since>
+						<version>12.0.0</version>
+					</since>
 					<synopsis>Music on hold class the agent listens to between calls.</synopsis>
 					<description>
 						<xi:include xpointer="xpointer(/docs/configInfo[@name='app_agent_pool']/description/note)" />
 					</description>
 				</configOption>
 				<configOption name="recordagentcalls">
-					<since><version>12.0.0</version></since>
+					<since>
+						<version>12.0.0</version>
+					</since>
 					<synopsis>Enable to automatically record calls the agent takes.</synopsis>
 					<description>
 						<para>Enable recording calls the agent takes automatically by
@@ -339,14 +363,18 @@
 					</description>
 				</configOption>
 				<configOption name="custom_beep">
-					<since><version>12.4.0</version></since>
+					<since>
+						<version>12.4.0</version>
+					</since>
 					<synopsis>Sound file played to alert the agent when a call is present.</synopsis>
 					<description>
 						<xi:include xpointer="xpointer(/docs/configInfo[@name='app_agent_pool']/description/note)" />
 					</description>
 				</configOption>
 				<configOption name="fullname">
-					<since><version>12.0.0</version></since>
+					<since>
+						<version>12.0.0</version>
+					</since>
 					<synopsis>A friendly name for the agent used in log messages.</synopsis>
 					<description>
 						<xi:include xpointer="xpointer(/docs/configInfo[@name='app_agent_pool']/description/note)" />
