@@ -41,7 +41,9 @@
 
 /*** DOCUMENTATION
 	<function name="GLOBAL" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.4.0</version>
+		</since>
 		<synopsis>
 			Gets or sets the global variable specified.
 		</synopsis>
@@ -55,7 +57,11 @@
 		</description>
 	</function>
 	<function name="GLOBAL_DELETE" language="en_US">
-		<since><version>18.21.0</version><version>20.6.0</version><version>21.1.0</version></since>
+		<since>
+			<version>18.21.0</version>
+			<version>20.6.0</version>
+			<version>21.1.0</version>
+		</since>
 		<synopsis>
 			Deletes a specified global variable.
 		</synopsis>
@@ -74,7 +80,11 @@
 		</see-also>
 	</function>
 	<function name="GLOBAL_EXISTS" language="en_US">
-		<since><version>18.21.0</version><version>20.6.0</version><version>21.1.0</version></since>
+		<since>
+			<version>18.21.0</version>
+			<version>20.6.0</version>
+			<version>21.1.0</version>
+		</since>
 		<synopsis>
 			Check if a global variable exists or not.
 		</synopsis>
@@ -91,7 +101,9 @@
 		</see-also>
 	</function>
 	<function name="SHARED" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.6.0</version>
+		</since>
 		<synopsis>
 			Gets or sets the shared variable specified.
 		</synopsis>
@@ -121,7 +133,9 @@
 	</function>
 	<managerEvent language="en_US" name="VarSet">
 		<managerEventInstance class="EVENT_FLAG_DIALPLAN">
-			<since><version>12.0.0</version></since>
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a variable is shared between channels.</synopsis>
 			<syntax>
 				<channel_snapshot/>
